create table CMS_SYSTEMPROPERTIES       (SYSTEMPROPERTY_ID int not null,
                                         SYSTEMPROPERTY_NAME VARCHAR(40) not null, 
                                         SYSTEMPROPERTY_VALUE blob,
                                         primary key(SYSTEMPROPERTY_ID),
                                         unique(SYSTEMPROPERTY_NAME));

create table CMS_USERS                  (USER_ID int not null,
                                         USER_NAME VARCHAR(32) not null,
                                         USER_PASSWORD VARCHAR(32) not null,
                                         USER_RECOVERY_PASSWORD VARCHAR(32) not null,
                                         USER_DESCRIPTION VARCHAR(255) not null,
                                         USER_FIRSTNAME VARCHAR(50) not null,
                                         USER_LASTNAME VARCHAR(50) not null,
                                         USER_EMAIL VARCHAR(100) not null,
                                         USER_LASTLOGIN DATETIME not null,
                                         USER_LASTUSED DATETIME not null,
                                         USER_FLAGS int not null,
                                         USER_INFO blob,
                                         USER_DEFAULT_GROUP_ID int not null,
                                         USER_ADDRESS VARCHAR(100) not null,
                                         USER_SECTION VARCHAR(50) not null,
                                         USER_TYPE int not null,
                                         primary key(USER_ID), unique(USER_NAME));

create table CMS_GROUPS                 (GROUP_ID int not null auto_increment,
                                         PARENT_GROUP_ID int not null,
                                         GROUP_NAME VARCHAR(16) not null,
                                         GROUP_DESCRIPTION VARCHAR(255) not null,
                                         GROUP_FLAGS int not null,
                                         primary key(GROUP_ID),
                                         unique(GROUP_NAME),
                                         key group_parentid (parent_group_id));

create table CMS_GROUPUSERS             (GROUP_ID int not null,
                                         USER_ID int not null,
                                         GROUPUSER_FLAGS int not null,
                                         key(GROUP_ID),
                                         key(USER_ID));

create table CMS_PROJECTS               (PROJECT_ID int not null, 
                                         USER_ID int not null,
                                         GROUP_ID int not null, 
                                         MANAGERGROUP_ID int not null,
                                         TASK_ID int not null,
                                         PROJECT_NAME VARCHAR(16) not null,
                                         PROJECT_DESCRIPTION VARCHAR(255) not null,
                                         PROJECT_FLAGS int not null,
                                         PROJECT_CREATEDATE datetime not null,
                                         PROJECT_TYPE int not null,
                                         primary key(PROJECT_ID), 
                                         key(PROJECT_NAME, PROJECT_CREATEDATE),
                                         key project_flags (project_flags),
                                         key projects_groupid (group_id),
                                         key projects_managerid (managergroup_id),
                                         key projects_userid (user_id),
                                         key projects_taskid (task_id),
                                         unique(PROJECT_NAME, PROJECT_CREATEDATE));

create table CMS_BACKUP_PROJECTS         (VERSION_ID int not null,
                                          PROJECT_ID int not null,
                                          PROJECT_NAME VARCHAR(16) not null,
                                          PROJECT_PUBLISHDATE datetime,
                                          PROJECT_PUBLISHED_BY int not null,
                                          PROJECT_PUBLISHED_BY_NAME VARCHAR(135),
                                          USER_ID int not null,
                                          USER_NAME VARCHAR(135),
                                          GROUP_ID int not null,
                                          GROUP_NAME VARCHAR(16),
                                          MANAGERGROUP_ID int not null,
                                          MANAGERGROUP_NAME VARCHAR(16),
                                          PROJECT_DESCRIPTION VARCHAR(255) not null,
                                          PROJECT_CREATEDATE datetime not null,
                                          PROJECT_TYPE int not null,
                                          TASK_ID int not null,
                                          primary key (VERSION_ID));

create table CMS_PROJECTRESOURCES       (PROJECT_ID int NOT NULL,
                                         RESOURCE_NAME VARCHAR(248) NOT NULL,
                                         primary key(PROJECT_ID, RESOURCE_NAME),
                                         index projectresource_resource_name (RESOURCE_NAME));

create table CMS_BACKUP_PROJECTRESOURCES (VERSION_ID int NOT NULL,
                                          PROJECT_ID int NOT NULL,
                                          RESOURCE_NAME VARCHAR(248) NOT NULL,
                                          PRIMARY KEY (VERSION_ID, PROJECT_ID, RESOURCE_NAME));


create table CMS_PROPERTYDEF            (PROPERTYDEF_ID int not null, 
                                         PROPERTYDEF_NAME VARCHAR(64) not null,
                                         RESOURCE_TYPE int not null,
                                         primary key(PROPERTYDEF_ID), 
                                         unique(PROPERTYDEF_NAME, RESOURCE_TYPE));

create table CMS_ONLINE_PROPERTYDEF      (PROPERTYDEF_ID int not null, 
                                         PROPERTYDEF_NAME VARCHAR(64) not null,
                                         RESOURCE_TYPE int not null,
                                         primary key(PROPERTYDEF_ID), 
                                         unique(PROPERTYDEF_NAME, RESOURCE_TYPE));
                                        
create table CMS_BACKUP_PROPERTYDEF      (PROPERTYDEF_ID int not null, 
                                         PROPERTYDEF_NAME VARCHAR(64) not null,
                                         RESOURCE_TYPE int not null,
                                         primary key(PROPERTYDEF_ID), 
                                         unique(PROPERTYDEF_NAME, RESOURCE_TYPE));

create table CMS_PROPERTIES             (PROPERTY_ID int not null,
                                         PROPERTYDEF_ID int not null,
                                         RESOURCE_ID int not null,
                                         PROPERTY_VALUE TEXT not null,
                                         primary key(PROPERTY_ID), 
                                         unique(PROPERTYDEF_ID, RESOURCE_ID));

create table CMS_ONLINE_PROPERTIES      (PROPERTY_ID int not null,
                                         PROPERTYDEF_ID int not null,
                                         RESOURCE_ID int not null,
                                         PROPERTY_VALUE TEXT not null,
                                         primary key(PROPERTY_ID), 
                                         unique(PROPERTYDEF_ID, RESOURCE_ID));
                                         
create table CMS_BACKUP_PROPERTIES      (PROPERTY_ID int not null,
                                         PROPERTYDEF_ID int not null,
                                         RESOURCE_ID int not null,
                                         PROPERTY_VALUE TEXT not null,
                                         VERSION_ID int,
                                         primary key(PROPERTY_ID), 
                                         unique(PROPERTYDEF_ID, RESOURCE_ID));
                                         
create table CMS_RESOURCES              (RESOURCE_ID int not null,
                                         PARENT_ID int not null,
                                         RESOURCE_NAME VARCHAR(248) not null,
                                         RESOURCE_TYPE int not null,
                                         RESOURCE_FLAGS int not null,
                                         USER_ID int not null,
                                         GROUP_ID int not null,
                                         PROJECT_ID int not null,
                                         FILE_ID int not null,
                                         ACCESS_FLAGS int not null,
                                         STATE int not null,
                                         LOCKED_BY int not null,
                                         LAUNCHER_TYPE int not null,
                                         LAUNCHER_CLASSNAME VARCHAR(255) not null,
                                         DATE_CREATED datetime not null,
                                         DATE_LASTMODIFIED datetime not null,
                                         RESOURCE_SIZE int not null,
                                         RESOURCE_LASTMODIFIED_BY int not null,
                                         primary key(RESOURCE_ID),
                                         key(RESOURCE_NAME,PROJECT_ID),
                                         key resource_fileid (FILE_ID),
                                         key resource_group (GROUP_ID),
                                         key resource_locked_by (LOCKED_BY),
                                         key resource_parentid (PARENT_ID),
                                         key resource_projectid (PROJECT_ID),
                                         key resources_state (STATE),
                                         key resources_type (RESOURCE_TYPE),
                                         key resource_userid (USER_ID),
                                         index parent_resource_type (PARENT_ID, RESOURCE_TYPE),
                                         index resources_project_type (PROJECT_ID, RESOURCE_TYPE),
                                         index resources_resourceid_project (RESOURCE_ID, PROJECT_ID),
                                         unique(RESOURCE_NAME));

create table CMS_ONLINE_RESOURCES       (RESOURCE_ID int not null,
                                         PARENT_ID int not null,
                                         RESOURCE_NAME VARCHAR(248) not null,
                                         RESOURCE_TYPE int not null,
                                         RESOURCE_FLAGS int not null,
                                         USER_ID int not null,
                                         GROUP_ID int not null,
                                         PROJECT_ID int not null,
                                         FILE_ID int not null,
                                         ACCESS_FLAGS int not null,
                                         STATE int not null,
                                         LOCKED_BY int not null,
                                         LAUNCHER_TYPE int not null,
                                         LAUNCHER_CLASSNAME VARCHAR(255) not null,
                                         DATE_CREATED datetime not null,
                                         DATE_LASTMODIFIED datetime not null,
                                         RESOURCE_SIZE int not null,
                                         RESOURCE_LASTMODIFIED_BY int not null,
                                         primary key(RESOURCE_ID),
                                         key(RESOURCE_NAME,PROJECT_ID),
                                         key resource_fileid (FILE_ID),
                                         key resource_group (GROUP_ID),
                                         key resource_locked_by (LOCKED_BY),
                                         key resource_parentid (PARENT_ID),
                                         key resource_projectid (PROJECT_ID),
                                         key resources_state (STATE),
                                         key resources_type (RESOURCE_TYPE),
                                         key resource_userid (USER_ID),
                                         index parent_resource_type (PARENT_ID, RESOURCE_TYPE),
                                         index resources_project_type (PROJECT_ID, RESOURCE_TYPE),
                                         unique(RESOURCE_NAME));
                                         
create table CMS_BACKUP_RESOURCES       (RESOURCE_ID int not null,
                                         PARENT_ID int not null,
                                         RESOURCE_NAME VARCHAR(248) not null,
                                         RESOURCE_TYPE int not null,
                                         RESOURCE_FLAGS int not null,
                                         USER_ID int not null,
                                         USER_NAME VARCHAR(135),
                                         GROUP_ID int not null,
                                         GROUP_NAME VARCHAR(16),
                                         PROJECT_ID int not null,
                                         FILE_ID int not null,
                                         ACCESS_FLAGS int not null,
                                         STATE int not null,
                                         LAUNCHER_TYPE int not null,
                                         LAUNCHER_CLASSNAME VARCHAR(255) not null,
                                         DATE_CREATED datetime not null,
                                         DATE_LASTMODIFIED datetime not null,
                                         RESOURCE_SIZE int not null,
                                         RESOURCE_LASTMODIFIED_BY int not null,
                                         RESOURCE_LASTMODIFIED_BY_NAME VARCHAR(135),
                                         VERSION_ID int not null,
                                         primary key(RESOURCE_ID),
                                         key(VERSION_ID,RESOURCE_NAME,PROJECT_ID),
                                         key resource_fileid (FILE_ID),
                                         key resource_group (GROUP_ID),
                                         key resource_parentid (PARENT_ID),
                                         key resource_projectid (PROJECT_ID),
                                         key resources_state (STATE),
                                         key resources_type (RESOURCE_TYPE),
                                         key resource_userid (USER_ID),
                                         index parent_resource_type (PARENT_ID, RESOURCE_TYPE),
                                         index resources_project_type (PROJECT_ID, RESOURCE_TYPE),
                                         index resources_resourceid_project (RESOURCE_ID, PROJECT_ID),
                                         unique(RESOURCE_NAME,VERSION_ID));
                                         
create table CMS_FILES                  (FILE_ID int not null,
                                         FILE_CONTENT mediumblob not null,
                                         primary key(FILE_ID));

create table CMS_ONLINE_FILES           (FILE_ID int not null,
                                         FILE_CONTENT mediumblob not null,
                                         primary key(FILE_ID));

create table CMS_BACKUP_FILES           (FILE_ID int not null,
                                         FILE_CONTENT mediumblob not null,
                                         VERSION_ID int,
                                         primary key(FILE_ID));

create table CMS_SYSTEMID               (TABLE_KEY varchar(255) not null,
                                         ID int not null,
                                         primary key(TABLE_KEY));

create table CMS_EXPORT_LINKS           (LINK_ID int not null,
                                         LINK varchar(255) not null,
                                         CREATEDATE DATETIME not null,
                                         PROCESSED bit,
                                         primary key (LINK_ID),
                                         key(LINK(100)),
                                         unique (LINK));

create table CMS_EXPORT_DEPENDENCIES    (LINK_ID int not null,
                                         RESOURCENAME varchar(255),
                                         key (LINK_ID),
                                         unique(LINK_ID, RESOURCENAME));

create table CMS_LINKS                  (PAGE_ID int not null,
                                         LINK_DEST varchar(255) not null,
                                         key (PAGE_ID),
                                         unique (PAGE_ID, LINK_DEST));

create table CMS_ONLINE_LINKS           (PAGE_ID int not null,
                                         LINK_DEST varchar(255) not null,
                                         key (PAGE_ID),
                                         unique (PAGE_ID, LINK_DEST));

create table CMS_SESSIONS               (SESSION_ID varchar(255) not null,
                                         SESSION_LASTUSED datetime not null,
                                         SESSION_DATA mediumblob not null,
                                         index session_lastused (SESSION_LASTUSED),
                                         primary key(SESSION_ID));
                                                                                 
                                         CREATE TABLE CMS_TASK (
                                           AUTOFINISH int(11),
                                           ENDTIME datetime,
                                           ESCALATIONTYPEREF int(11),
                                           ID int(11) NOT NULL,
                                           INITIATORUSERREF int(11),
                                           MILESTONEREF int(11),
                                           NAME varchar(254),
                                           ORIGINALUSERREF int(11),
                                           AGENTUSERREF int(11),
                                           PARENT int(11),
                                           PERCENTAGE varchar(50),
                                           PERMISSION varchar(50),
                                           PRIORITYREF int(11) DEFAULT '2',
                                           ROLEREF int(11),
                                           ROOT int(11),
                                           STARTTIME datetime,
                                           STATE int(11),
                                           TASKTYPEREF int(11),
                                           TIMEOUT datetime,
                                           WAKEUPTIME datetime,
                                           HTMLLINK varchar(254),
                                           ESTIMATETIME int(11) DEFAULT '86400',
                                           PRIMARY KEY (id)
                                         );
                                                                                 
                                         CREATE TABLE CMS_TASKTYPE (
                                           AUTOFINISH int(11),
                                           ESCALATIONTYPEREF int(11),
                                           HTMLLINK varchar(254),
                                           ID int(11) NOT NULL,
                                           NAME varchar(50),
                                           PERMISSION varchar(50),
                                           PRIORITYREF int(11),
                                           ROLEREF int(11),
                                           PRIMARY KEY (id)
                                         );
                                                                                 
                                         CREATE TABLE CMS_TASKLOG (
                                           COMENT text,
                                           EXTERNALUSERNAME varchar(254),
                                           ID int(11) NOT NULL,
                                           STARTTIME datetime,
                                           TASKREF int(11),
                                           USERREF int(11),
                                           TYPE int(18) DEFAULT '0',
                                           PRIMARY KEY (id)
                                         );
                                         
                                         CREATE TABLE CMS_TASKPAR (
                                           ID int(11) NOT NULL ,
                                           PARNAME varchar(50),
                                           PARVALUE varchar(50),
                                           REF int(11),
                                           PRIMARY KEY (id)
                                         );
create table CMS_MODULE_ONLINE_MASTER   (MASTER_ID              int not null,
                                         SUB_ID                 int not null,
                                         USER_ID                int not null,
                                         GROUP_ID               int not null,
                                         PROJECT_ID             int not null,
                                         ACCESS_FLAGS           int not null,
                                         STATE                  int not null,
                                         LOCKED_BY              int not null,
                                         LASTMODIFIED_BY        int not null,
                                         DATE_CREATED           datetime not null,
                                         DATE_LASTMODIFIED      datetime not null,

                                         PUBLICATION_DATE       datetime,
                                         PURGE_DATE             datetime,
                                         FLAGS                  int,
                                         FEED_ID                int,
                                         FEED_REFERENCE         int,
                                         FEED_FILENAME          varchar(255),
                                         TITLE                  varchar(255),
                                         DATA_BIG_0             TEXT,
                                         DATA_BIG_1             TEXT,
                                         DATA_BIG_2             TEXT,
                                         DATA_BIG_3             TEXT,
                                         DATA_BIG_4             TEXT,
                                         DATA_BIG_5             TEXT,
                                         DATA_BIG_6             TEXT,
                                         DATA_BIG_7             TEXT,
                                         DATA_BIG_8             TEXT,
                                         DATA_BIG_9             TEXT,
                                         DATA_MEDIUM_0          TEXT,
                                         DATA_MEDIUM_1          TEXT,
                                         DATA_MEDIUM_2          TEXT,
                                         DATA_MEDIUM_3          TEXT,
                                         DATA_MEDIUM_4          TEXT,
                                         DATA_MEDIUM_5          TEXT,
                                         DATA_MEDIUM_6          TEXT,
                                         DATA_MEDIUM_7          TEXT,
                                         DATA_MEDIUM_8          TEXT,
                                         DATA_MEDIUM_9          TEXT,
                                         DATA_SMALL_0           TEXT,
                                         DATA_SMALL_1           TEXT,
                                         DATA_SMALL_2           TEXT,
                                         DATA_SMALL_3           TEXT,
                                         DATA_SMALL_4           TEXT,
                                         DATA_SMALL_5           TEXT,
                                         DATA_SMALL_6           TEXT,
                                         DATA_SMALL_7           TEXT,
                                         DATA_SMALL_8           TEXT,
                                         DATA_SMALL_9           TEXT,
                                         DATA_SMALL_10          TEXT,
                                         DATA_SMALL_11          TEXT,
                                         DATA_SMALL_12          TEXT,
                                         DATA_SMALL_13          TEXT,
                                         DATA_SMALL_14          TEXT,
                                         DATA_SMALL_15          TEXT,
                                         DATA_SMALL_16          TEXT,
                                         DATA_SMALL_17          TEXT,
                                         DATA_SMALL_18          TEXT,
                                         DATA_SMALL_19          TEXT,
                                         DATA_SMALL_20          TEXT,
                                         DATA_SMALL_21          TEXT,
                                         DATA_SMALL_22          TEXT,
                                         DATA_SMALL_23          TEXT,
                                         DATA_SMALL_24          TEXT,
                                         DATA_SMALL_25          TEXT,
                                         DATA_SMALL_26          TEXT,
                                         DATA_SMALL_27          TEXT,
                                         DATA_SMALL_28          TEXT,
                                         DATA_SMALL_29          TEXT,
                                         DATA_SMALL_30          TEXT,
                                         DATA_SMALL_31          TEXT,
                                         DATA_SMALL_32          TEXT,
                                         DATA_SMALL_33          TEXT,
                                         DATA_SMALL_34          TEXT,
                                         DATA_SMALL_35          TEXT,
                                         DATA_SMALL_36          TEXT,
                                         DATA_SMALL_37          TEXT,
                                         DATA_SMALL_38          TEXT,
                                         DATA_SMALL_39          TEXT,
                                         DATA_INT_0             int,
                                         DATA_INT_1             int,
                                         DATA_INT_2             int,
                                         DATA_INT_3             int,
                                         DATA_INT_4             int,
                                         DATA_INT_5             int,
                                         DATA_INT_6             int,
                                         DATA_INT_7             int,
                                         DATA_INT_8             int,
                                         DATA_INT_9             int,
                                         DATA_REFERENCE_0       int,
                                         DATA_REFERENCE_1       int,
                                         DATA_REFERENCE_2       int,
                                         DATA_REFERENCE_3       int,
                                         DATA_REFERENCE_4       int,
                                         DATA_REFERENCE_5       int,
                                         DATA_REFERENCE_6       int,
                                         DATA_REFERENCE_7       int,
                                         DATA_REFERENCE_8       int,
                                         DATA_REFERENCE_9       int,
                                         DATA_DATE_0            datetime,
                                         DATA_DATE_1            datetime,
                                         DATA_DATE_2            datetime,
                                         DATA_DATE_3            datetime,
                                         DATA_DATE_4            datetime,
                                         index iSUB_ID (SUB_ID),
                                         primary key(MASTER_ID));
                                         
create table CMS_MODULE_ONLINE_CHANNEL_REL
                                        (MASTER_ID              int not null,
                                         CHANNEL_ID             int not null,
                                         primary key(CHANNEL_ID, MASTER_ID));

create table CMS_MODULE_ONLINE_MEDIA    (MEDIA_ID               int not null,
                                         MASTER_ID              int not null,
                                         MEDIA_POSITION         int not null,
                                         MEDIA_WIDTH            int not null,
                                         MEDIA_HEIGHT           int not null,
                                         MEDIA_SIZE             int not null,
                                         MEDIA_MIMETYPE         varchar(255),
                                         MEDIA_TYPE             int not null,
                                         MEDIA_TITLE            varchar(255),
                                         MEDIA_NAME             varchar(255),
                                         MEDIA_DESCRIPTION      TEXT not null,
                                         MEDIA                  longblob not null,
                                         key(MASTER_ID),
                                         primary key(MEDIA_ID));
                                         

create table CMS_MODULE_MASTER          (MASTER_ID              int not null,
                                         SUB_ID                 int not null,
                                         USER_ID                int not null,
                                         GROUP_ID               int not null,
                                         PROJECT_ID             int not null,
                                         ACCESS_FLAGS           int not null,
                                         STATE                  int not null,
                                         LOCKED_BY              int not null,
                                         LASTMODIFIED_BY        int not null,
                                         DATE_CREATED           datetime not null,
                                         DATE_LASTMODIFIED      datetime not null,
                                         
                                         PUBLICATION_DATE       datetime,
                                         PURGE_DATE             datetime,
                                         FLAGS                  int not null,
                                         FEED_ID                int not null,
                                         FEED_REFERENCE         int not null,
                                         FEED_FILENAME          varchar(255),
                                         TITLE                  varchar(255),
                                         DATA_BIG_0             TEXT,
                                         DATA_BIG_1             TEXT,
                                         DATA_BIG_2             TEXT,
                                         DATA_BIG_3             TEXT,
                                         DATA_BIG_4             TEXT,
                                         DATA_BIG_5             TEXT,
                                         DATA_BIG_6             TEXT,
                                         DATA_BIG_7             TEXT,
                                         DATA_BIG_8             TEXT,
                                         DATA_BIG_9             TEXT,
                                         DATA_MEDIUM_0          TEXT,
                                         DATA_MEDIUM_1          TEXT,
                                         DATA_MEDIUM_2          TEXT,
                                         DATA_MEDIUM_3          TEXT,
                                         DATA_MEDIUM_4          TEXT,
                                         DATA_MEDIUM_5          TEXT,
                                         DATA_MEDIUM_6          TEXT,
                                         DATA_MEDIUM_7          TEXT,
                                         DATA_MEDIUM_8          TEXT,
                                         DATA_MEDIUM_9          TEXT,
                                         DATA_SMALL_0           TEXT,
                                         DATA_SMALL_1           TEXT,
                                         DATA_SMALL_2           TEXT,
                                         DATA_SMALL_3           TEXT,
                                         DATA_SMALL_4           TEXT,
                                         DATA_SMALL_5           TEXT,
                                         DATA_SMALL_6           TEXT,
                                         DATA_SMALL_7           TEXT,
                                         DATA_SMALL_8           TEXT,
                                         DATA_SMALL_9           TEXT,
                                         DATA_SMALL_10          TEXT,
                                         DATA_SMALL_11          TEXT,
                                         DATA_SMALL_12          TEXT,
                                         DATA_SMALL_13          TEXT,
                                         DATA_SMALL_14          TEXT,
                                         DATA_SMALL_15          TEXT,
                                         DATA_SMALL_16          TEXT,
                                         DATA_SMALL_17          TEXT,
                                         DATA_SMALL_18          TEXT,
                                         DATA_SMALL_19          TEXT,
                                         DATA_SMALL_20          TEXT,
                                         DATA_SMALL_21          TEXT,
                                         DATA_SMALL_22          TEXT,
                                         DATA_SMALL_23          TEXT,
                                         DATA_SMALL_24          TEXT,
                                         DATA_SMALL_25          TEXT,
                                         DATA_SMALL_26          TEXT,
                                         DATA_SMALL_27          TEXT,
                                         DATA_SMALL_28          TEXT,
                                         DATA_SMALL_29          TEXT,
                                         DATA_SMALL_30          TEXT,
                                         DATA_SMALL_31          TEXT,
                                         DATA_SMALL_32          TEXT,
                                         DATA_SMALL_33          TEXT,
                                         DATA_SMALL_34          TEXT,
                                         DATA_SMALL_35          TEXT,
                                         DATA_SMALL_36          TEXT,
                                         DATA_SMALL_37          TEXT,
                                         DATA_SMALL_38          TEXT,
                                         DATA_SMALL_39          TEXT,
                                         DATA_INT_0             int,
                                         DATA_INT_1             int,
                                         DATA_INT_2             int,
                                         DATA_INT_3             int,
                                         DATA_INT_4             int,
                                         DATA_INT_5             int,
                                         DATA_INT_6             int,
                                         DATA_INT_7             int,
                                         DATA_INT_8             int,
                                         DATA_INT_9             int,
                                         DATA_REFERENCE_0       int,
                                         DATA_REFERENCE_1       int,
                                         DATA_REFERENCE_2       int,
                                         DATA_REFERENCE_3       int,
                                         DATA_REFERENCE_4       int,
                                         DATA_REFERENCE_5       int,
                                         DATA_REFERENCE_6       int,
                                         DATA_REFERENCE_7       int,
                                         DATA_REFERENCE_8       int,
                                         DATA_REFERENCE_9       int,
                                         DATA_DATE_0            datetime,
                                         DATA_DATE_1            datetime,
                                         DATA_DATE_2            datetime,
                                         DATA_DATE_3            datetime,
                                         DATA_DATE_4            datetime,
                                         index iSUB_ID (SUB_ID),
                                         primary key(MASTER_ID));

create table CMS_MODULE_CHANNEL_REL
                                        (MASTER_ID              int not null,
                                         CHANNEL_ID             int not null,
                                         primary key(CHANNEL_ID, MASTER_ID));

create table CMS_MODULE_MEDIA           (MEDIA_ID               int not null,
                                         MASTER_ID              int not null,
                                         MEDIA_POSITION         int not null,
                                         MEDIA_WIDTH            int not null,
                                         MEDIA_HEIGHT           int not null,
                                         MEDIA_SIZE             int not null,
                                         MEDIA_MIMETYPE         varchar(255),
                                         MEDIA_TYPE             int not null,
                                         MEDIA_TITLE            varchar(255),
                                         MEDIA_NAME             varchar(255),
                                         MEDIA_DESCRIPTION      TEXT not null,
                                         MEDIA                  longblob not null,
                                         key(MASTER_ID),
                                         primary key(MEDIA_ID));


create table CMS_MODULE_BACKUP_MASTER   (MASTER_ID              int not null,
                                         SUB_ID                 int not null,
                                         USER_ID                int not null,
                                         GROUP_ID               int not null,
                                         PROJECT_ID             int not null,
                                         ACCESS_FLAGS           int not null,
                                         STATE                  int not null,
                                         LOCKED_BY              int not null,
                                         LASTMODIFIED_BY        int not null,
                                         DATE_CREATED           datetime not null,
                                         DATE_LASTMODIFIED      datetime not null,
                                         PUBLICATION_DATE       datetime,
                                         PURGE_DATE             datetime,
                                         FLAGS                  int not null,
                                         FEED_ID                int not null,
                                         FEED_REFERENCE         int not null,
                                         FEED_FILENAME          varchar(255),
                                         TITLE                  varchar(255),
                                         DATA_BIG_0             TEXT,
                                         DATA_BIG_1             TEXT,
                                         DATA_BIG_2             TEXT,
                                         DATA_BIG_3             TEXT,
                                         DATA_BIG_4             TEXT,
                                         DATA_BIG_5             TEXT,
                                         DATA_BIG_6             TEXT,
                                         DATA_BIG_7             TEXT,
                                         DATA_BIG_8             TEXT,
                                         DATA_BIG_9             TEXT,
                                         DATA_MEDIUM_0          TEXT,
                                         DATA_MEDIUM_1          TEXT,
                                         DATA_MEDIUM_2          TEXT,
                                         DATA_MEDIUM_3          TEXT,
                                         DATA_MEDIUM_4          TEXT,
                                         DATA_MEDIUM_5          TEXT,
                                         DATA_MEDIUM_6          TEXT,
                                         DATA_MEDIUM_7          TEXT,
                                         DATA_MEDIUM_8          TEXT,
                                         DATA_MEDIUM_9          TEXT,
                                         DATA_SMALL_0           TEXT,
                                         DATA_SMALL_1           TEXT,
                                         DATA_SMALL_2           TEXT,
                                         DATA_SMALL_3           TEXT,
                                         DATA_SMALL_4           TEXT,
                                         DATA_SMALL_5           TEXT,
                                         DATA_SMALL_6           TEXT,
                                         DATA_SMALL_7           TEXT,
                                         DATA_SMALL_8           TEXT,
                                         DATA_SMALL_9           TEXT,
                                         DATA_SMALL_10          TEXT,
                                         DATA_SMALL_11          TEXT,
                                         DATA_SMALL_12          TEXT,
                                         DATA_SMALL_13          TEXT,
                                         DATA_SMALL_14          TEXT,
                                         DATA_SMALL_15          TEXT,
                                         DATA_SMALL_16          TEXT,
                                         DATA_SMALL_17          TEXT,
                                         DATA_SMALL_18          TEXT,
                                         DATA_SMALL_19          TEXT,
                                         DATA_SMALL_20          TEXT,
                                         DATA_SMALL_21          TEXT,
                                         DATA_SMALL_22          TEXT,
                                         DATA_SMALL_23          TEXT,
                                         DATA_SMALL_24          TEXT,
                                         DATA_SMALL_25          TEXT,
                                         DATA_SMALL_26          TEXT,
                                         DATA_SMALL_27          TEXT,
                                         DATA_SMALL_28          TEXT,
                                         DATA_SMALL_29          TEXT,
                                         DATA_SMALL_30          TEXT,
                                         DATA_SMALL_31          TEXT,
                                         DATA_SMALL_32          TEXT,
                                         DATA_SMALL_33          TEXT,
                                         DATA_SMALL_34          TEXT,
                                         DATA_SMALL_35          TEXT,
                                         DATA_SMALL_36          TEXT,
                                         DATA_SMALL_37          TEXT,
                                         DATA_SMALL_38          TEXT,
                                         DATA_SMALL_39          TEXT,
                                         DATA_INT_0             int,
                                         DATA_INT_1             int,
                                         DATA_INT_2             int,
                                         DATA_INT_3             int,
                                         DATA_INT_4             int,
                                         DATA_INT_5             int,
                                         DATA_INT_6             int,
                                         DATA_INT_7             int,
                                         DATA_INT_8             int,
                                         DATA_INT_9             int,
                                         DATA_REFERENCE_0       int,
                                         DATA_REFERENCE_1       int,
                                         DATA_REFERENCE_2       int,
                                         DATA_REFERENCE_3       int,
                                         DATA_REFERENCE_4       int,
                                         DATA_REFERENCE_5       int,
                                         DATA_REFERENCE_6       int,
                                         DATA_REFERENCE_7       int,
                                         DATA_REFERENCE_8       int,
                                         DATA_REFERENCE_9       int,
                                         DATA_DATE_0            datetime,
                                         DATA_DATE_1            datetime,
                                         DATA_DATE_2            datetime,
                                         DATA_DATE_3            datetime,
                                         DATA_DATE_4            datetime,
                                         VERSION_ID             int not null,
                                         USER_NAME              VARCHAR(135),
                                         GROUP_NAME             VARCHAR(16),
                                         LASTMODIFIED_BY_NAME   VARCHAR(135),
                                         primary key(MASTER_ID, VERSION_ID));

create table CMS_MODULE_BACKUP_MEDIA    (MEDIA_ID               int not null,
                                         MASTER_ID              int not null,
                                         MEDIA_POSITION         int not null,
                                         MEDIA_WIDTH            int not null,
                                         MEDIA_HEIGHT           int not null,
                                         MEDIA_SIZE             int not null,
                                         MEDIA_MIMETYPE         varchar(255),
                                         MEDIA_TYPE             int not null,
                                         MEDIA_TITLE            varchar(255),
                                         MEDIA_NAME             varchar(255),
                                         MEDIA_DESCRIPTION      TEXT not null,
                                         MEDIA                  longblob not null,
                                         VERSION_ID             int not null,
                                         key(MASTER_ID),
                                         primary key(MEDIA_ID, VERSION_ID));

create table CMS_WEBUSERS
(  USER_ID                  INT not null,
   USER_MEMBER_ID           VARCHAR(255),
   USER_SALUTATION          VARCHAR(255),
   USER_TITLE               VARCHAR(255),
   USER_PWD		    VARCHAR(255),   
   USER_PWD_QUESTION        VARCHAR(255),   
   USER_PWD_ANSWER          VARCHAR(255),        
   USER_CITY                VARCHAR(255),
   USER_POSTCODE            VARCHAR(255),
   USER_STATE               VARCHAR(255),
   USER_COUNTRY             VARCHAR(255),
   USER_ADDRESS_TYPE        INT,
   USER_BIRTHDAY            DATETIME,
   USER_PHONE               VARCHAR(255),
   USER_FAX                 VARCHAR(255),
   USER_MOBILE              VARCHAR(255),
   USER_ACCEPT              INT,   
   USER_RECOMMENDED_BY	    VARCHAR(255), 
   USER_PROFESSION          VARCHAR(255),
   USER_COMPANY             VARCHAR(255),
   USER_DEPARTMENT	    VARCHAR(255),
   USER_POSITION            VARCHAR(255),         
   USER_ACCOUNT_NUMBER      VARCHAR(255),
   USER_BANK_NUMBER         VARCHAR(255),
   USER_BANK                VARCHAR(255),
   USER_NEWSLETTER          VARCHAR(255),   
   USER_EXTRAINFO_1         VARCHAR(255),
   USER_EXTRAINFO_2         VARCHAR(255),
   USER_EXTRAINFO_3         VARCHAR(255),
   USER_EXTRAINFO_4         VARCHAR(255),
   USER_EXTRAINFO_5         VARCHAR(255),
   USER_EXTRAINFO_6         VARCHAR(255),
   USER_EXTRAINFO_7         VARCHAR(255),
   USER_EXTRAINFO_8         VARCHAR(255),
   USER_EXTRAINFO_9         VARCHAR(255),
   USER_EXTRAINFO_10        VARCHAR(255),
   USER_EXTRAINFO_11        VARCHAR(255),
   USER_EXTRAINFO_12        VARCHAR(255),
   USER_EXTRAINFO_13        VARCHAR(255),
   USER_EXTRAINFO_14        VARCHAR(255),
   USER_EXTRAINFO_15        VARCHAR(255),
   USER_EXTRAINFO_16        VARCHAR(255),
   USER_EXTRAINFO_17        VARCHAR(255),
   USER_EXTRAINFO_18        VARCHAR(255),
   USER_EXTRAINFO_19        TEXT,
   USER_EXTRAINFO_20        TEXT,
   USER_PICTURE		    MEDIUMBLOB,
   USER_PICTURE_NAME	    VARCHAR(255),         
   USER_CREATE_DATE         DATETIME,
   USER_LASTCHANGE_BY       VARCHAR(255),
   USER_LASTCHANGE_DATE     DATETIME,
   LOCKSTATE                INT,
   primary key (USER_ID)
);